﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using WpWinNl;
using WpWinNl.Utilities;

namespace TwoPhonePong
{
  public partial class Help
  {
    private readonly Dictionary<MediaElement, Uri> sources = new Dictionary<MediaElement, Uri>();
    public Help()
    {
      InitializeComponent();
      VideoPivot.Loaded += VideoPivotLoaded;
      VideoPivot.LoadedPivotItem += VideoPivotLoadedPivotItem;
    }

    void VideoPivotLoaded(object sender, RoutedEventArgs e)
    {
      VideoPivot.GetVisualDescendents().OfType<MediaElement>().ForEach(StoreMediaElementReference);
      PlayMovieOnPivotItem((PivotItem)VideoPivot.SelectedItem);
    }

    private void VideoPivotLoadedPivotItem(object sender, PivotItemEventArgs e)
    {
      PlayMovieOnPivotItem(e.Item);
    }

    private void PlayMovieOnPivotItem(PivotItem e)
    {
      var mediaElement = e.GetVisualDescendents().OfType<MediaElement>().FirstOrDefault();
      VideoPivot.GetVisualDescendents().OfType<MediaElement>().Where(p => p != mediaElement).ForEach(
        p =>
        {
          p.Stop();
          p.Source = null;
        });

      if (mediaElement != null)
      {
        mediaElement.Position = new TimeSpan(0);
        if (!sources.ContainsKey(mediaElement))
        {
          StoreMediaElementReference(mediaElement);
        }
        mediaElement.Source = sources[mediaElement];
      }
    }


    private void MovieMediaElementMediaEnded(object sender, RoutedEventArgs e)
    {
      var mediaElement = sender as MediaElement;
      if (mediaElement != null)
      {
        mediaElement.Position = new TimeSpan(0);
        mediaElement.Play();
      }
    }

    private void StoreMediaElementReference(MediaElement mediaElement)
    {
      sources.Add(mediaElement, mediaElement.Source);
      mediaElement.Source = null;
      mediaElement.AutoPlay = false;
      mediaElement.MediaEnded += MovieMediaElementMediaEnded;
      mediaElement.MediaOpened += MovieMediaElementMediaEnded;
    }

    protected override void OnNavigatedFrom(NavigationEventArgs e)
    {
      sources.Keys.ForEach(p =>
                           {
                             p.Source = null;
                             p.MediaEnded -= MovieMediaElementMediaEnded;
                             p.MediaOpened -= MovieMediaElementMediaEnded;
                           });
      VideoPivot.Loaded -= VideoPivotLoaded;
      VideoPivot.LoadedPivotItem -= VideoPivotLoadedPivotItem;
      base.OnNavigatedFrom(e);
    }
  }
}